"""
FILE: django_probes/management/commands/wait_for_database.py
"""
from django.core.management.base import BaseCommand
from django.db import connection
from time import sleep


class Command(BaseCommand):
    """
    A readiness probe you can use for Kubernetes.

    If the default database is ready, i.e. willing to accept connections
    and handling requests, then this call will succeed silently. Otherwise
    it will throw an exception.
    """
    help = 'Probes for database availability'

    def handle(self, *args, **options):
        """Throw an exception if database is not (yet) available."""
        wait_for_db_seconds = 1
        stable_for_seconds = 4

        for uptime in range(stable_for_seconds):

            # loop until we have a database connection
            while True:
                try:
                    connection.cursor().execute('SELECT')
                    break
                except:  # TODO: use appropriate exception type
                    print('Waiting for database')
                    sleep(wait_for_db_seconds)

            print('Connection alive for > {uptime}s'.format(uptime=uptime))
            sleep(1)



#!/usr/bin/env python3
"""
Packaging setup to test access to the database
"""
from os.path import abspath, dirname, join
from setuptools import find_packages, setup

import django_probes as package


def read_file(filename):
    """Get the contents of a file"""
    here = abspath(dirname(__file__))
    with open(join(here, filename), encoding='utf-8') as file:
        return file.read()


setup(
    name=package.__name__,
    version=package.__version__,
    license=package.__license__,
    author=package.__author__,
    author_email=package.__email__,
    description=package.__doc__.strip(),
    long_description=read_file('README.rst'),
    url=package.__url__,
    packages=find_packages(exclude=['test*']),
    include_package_data=True,
    keywords=['django', 'database', 'probes', 'kubernetes'],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Framework :: Django :: 2.0',
        'Framework :: Django :: 2.1',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
)
